# Objectidentifier

A URI or CURIE that represents an object in the model.

URI: shex:iri

* [base](https://w3id.org/linkml/base): ElementIdentifier


* [repr](https://w3id.org/linkml/repr): str




## Identifier and Mapping Information


